class CommentoPlugin {
	constructor (API, name, config) {
		this.API = API;
		this.name = name;
		this.config = config;
	}

	addInsertions () {
		this.API.addInsertion('customCommentsCode', this.addPostScripts, 1, this);
	}

	addPostScripts (rendererInstance, context) {
		let url = '';
		let uniquePageID = '';
		let previewNotice = '';
		let cookieBannerGroup = 'text/javascript';
		let consentScriptToLoad = '';
		let consentNotice = '';
		let selfHostedURL = 'https://cdn.commento.io/js/commento.js';
		let cssHeaderClass = ` class="${this.config.cssHeaderClass}"`;
		let cssWrapperClass = ` class="${this.config.cssWrapperClass}"`;
		let cssInnerWrapperClass = ` class="${this.config.cssInnerWrapperClass}"`;

		if (this.config.selfHostedURL) {
			selfHostedURL = this.config.selfHostedURL;
		}

		if (!this.config.cssHeaderClass) {
			cssHeaderClass = '';
		}

		if (!this.config.cssWrapperClass) {
			cssWrapperClass = '';
		}

		if (!this.config.cssInnerWrapperClass) {
			cssInnerWrapperClass = '';
		}

		if (rendererInstance.globalContext && rendererInstance.globalContext.website) {
			url = rendererInstance.globalContext.website.pageUrl;
		}

		if (context && context.post && context.post.id) {
			uniquePageID = context.post.id;
		} else {
			uniquePageID = url;
		}

		let heading = `
			<h${this.config.headingLevel}${cssHeaderClass}>
		        ${this.config.textHeader}
		    </h${this.config.headingLevel}>
	    `;

	    if (!this.config.textHeader) {
	    	heading = '';
	    }

		 if (rendererInstance.previewMode) {
			previewNotice = `<div style="background: #f0f0f0; border: 1px solid #ccc; border-radius: 5px; color: #666; display: block; padding: 10px; text-align: center; width: 100%;">Commento comments are not working and may display error messages in the preview mode. </div>`;
		}

		let scriptToLoad = `
			(function () {
				var d = document, s = d.createElement('script');
				s.src = '${selfHostedURL}';
				s.defer = true;
				s.setAttribute('data-no-fonts','true');
				s.setAttribute('data-page-id','${uniquePageID}');
				s.setAttribute('data-hide-deleted','${this.config.hideDeletedComments}');
				(d.head || d.body).appendChild(s);
			})();
		`;

		if (this.config.lazyload) {
			scriptToLoad = `
				var commento_element_to_check = document.getElementById('commento');

				if ('IntersectionObserver' in window) {
					var iObserver = new IntersectionObserver(
						(entries, observer) => {
							entries.forEach(entry => {
								if (entry.intersectionRatio >= 0.1) {
									(function () {
										var d = document, s = d.createElement('script');
										s.defer = true;
										s.setAttribute('data-no-fonts','true');
										s.setAttribute('data-page-id','${uniquePageID}');
										s.setAttribute('data-hide-deleted','${this.config.hideDeletedComments}');
										s.src = '${selfHostedURL}';									
										(d.head || d.body).appendChild(s);
									})();
									observer.unobserve(entry.target);
								}
							});
						},
						{
							threshold: [0, 0.2, 0.5, 1]
						}
					);

					iObserver.observe(commento_element_to_check);
				} else {
					(function () {
						var d = document, s = d.createElement('script');
						s.defer = true;
						s.setAttribute('data-no-fonts','true');
						s.setAttribute('data-page-id','${uniquePageID}');
						s.setAttribute('data-hide-deleted','${this.config.hideDeletedComments}');
						s.src = '${selfHostedURL}';
						(d.head || d.body).appendChild(s);
					})();
				}
			`;
		}

		if (this.config.cookieBannerIntegration) {
			cookieBannerGroup = 'gdpr-blocker/' + this.config.cookieBannerGroup.trim();
			consentScriptToLoad = `document.body.addEventListener('publii-cookie-banner-unblock-${this.config.cookieBannerGroup.trim()}', function () {
				document.getElementById('commento-no-consent-info').style.display = 'none';
			}, false);`;
			consentNotice = `<div
				data-gdpr-group="${cookieBannerGroup}"
				id="commento-no-consent-info" 
				style="background: #f0f0f0; border: 1px solid #ccc; border-radius: 5px; color: #666; display: block; padding: 10px; text-align: center; width: 100%;">
				${this.config.cookieBannerNoConsentText}
			</div>`;
		}

		return `
			<div${cssWrapperClass}>
	            <div${cssInnerWrapperClass}>
	               	${heading}							
							${previewNotice}			
					<div id="commento"></div>
					<noscript>
						${this.config.textFallback}
					</noscript>
					${consentNotice}
					<script type="${cookieBannerGroup}">
						${scriptToLoad}
					</script>
					<script type="text/javascript">
						${consentScriptToLoad}
					</script>
				</div>
			</div>
    	`;
	}
}

module.exports = CommentoPlugin;